@@ -9,11 +9,10 @@ set.seed(1)
 
 simdata <- simulate_tweedie(weight = .2, ancillary = 1.15, link = "log")
 
-ggplot(simdata, aes(x = Y)) + 
+ggplot(simdata, aes(x = Y)) +
   geom_histogram(bins = 30)
 
 ## ----model2, echo=TRUE--------------------------------------------------------
-glmModel <- cpglm(Y ~ X1, data =simdata, link = "log")
-summary(glmModel)
-
+glm_model <- cpglm(Y ~ X1, data = simdata, link = "log")
+summary(glm_model)
 
